@@ -1,13 +1,14 @@
 /*****************************************************************************
  * parser.cpp : SAP configuration file parser
  ****************************************************************************
- * Copyright (C) 1998-2002 VideoLAN
+ * Copyright (C) 1998-2004 VideoLAN
  * $Id: parser.cpp,v 1.9 2003/11/10 00:42:30 zorglub Exp $
  *
  * Authors: Arnaud Schauly <gitan@via.ecp.fr>
  *          Clment Stenac <zorglub@via.ecp.fr>
  *          Damien Lucas <nitrox@videolan.org>
  *          Philippe Van Hecke <philippe.vanhecke@belnet.be>
+ *          Derk-Jan Hartman <hartman at videolan dot org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,6 +49,7 @@ Config::Config(string f)
     file	=	f;
     ttl		=	DEFAULT_TTL;
     scope	=	DEFAULT_SCOPE;
+    delay	=	DEFAULT_DELAY;
     type	=	TYPE_SAP;
     reverse	=	false;
 }
@@ -67,6 +69,16 @@ void Config::SetTTL(unsigned int t)
     ttl=t;
 }
 
+unsigned int Config::GetDelay()
+{
+    return delay;
+}
+
+void Config::SetDelay(unsigned int d)
+{
+    delay=d;
+}
+
 bool Config::GetDaemonMode(void)
 {
     return daemon;
@@ -208,6 +220,13 @@ int Config::Parse()
             ttl=atoi(tline);
         }
 
+        /* Set SAP Delay  (delay is a member of config) */
+        if(strstr(line,"sap_delay="))
+        {
+            strgeta(line,tline,'=');
+            delay=atoi(tline);
+        }
+
         /* Set SAP IP Version  (ipversion is a member of config) */
         if(strstr(line,"sap_ipversion="))
         {
