@@ -1,7 +1,7 @@
 /*****************************************************************************
  * parser.h : SAP configuration file parser definition
  ****************************************************************************
- * Copyright (C) 1998-2003 VideoLAN
+ * Copyright (C) 1998-2004 VideoLAN
  * $Id: parser.h,v 1.5 2003/08/10 12:44:18 zorglub Exp $ 
  *
  * Authors: Fabrice Ollivier <cif@via.ecp.fr>
@@ -32,6 +32,8 @@ class Config
     int Parse();
     unsigned int GetTTL();
     void SetTTL(unsigned int);
+    unsigned int GetDelay();
+    void SetDelay(unsigned int);
     bool GetDaemonMode(void);
     void SetDaemonMode(bool);
     bool GetReverse(void);
@@ -48,6 +50,7 @@ class Config
   private:
     string file;
     int ttl;
+    int delay;
     int ipversion;
     char * scope;
     int type;
